<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.insightengine.online/
 * @since             1.0.0
 * @package           Aielatex
 *
 * @wordpress-plugin
 * Plugin Name:       AI Engine LaTeX
 * Plugin URI:        https://www.insightengine.online/
 * Description:       Gives AI Engine the support for streaming LaTeX expressions.
 * Version:           1.0.0
 * Author:            Kevin K. @ Insight Engine
 * Author URI:        https://www.insightengine.online//
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       aielatex
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'AIELATEX_VERSION', '1.0.0' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-aielatex.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_aielatex() {

	$plugin = new Aielatex();
	$plugin->run();

}
run_aielatex();

require 'plugin-update-checker/plugin-update-checker.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

add_action('plugins_loaded', function() {
	if (is_admin() && current_user_can('manage_options')) {
		$token = file_get_contents(plugin_dir_path(__FILE__) . 'LICENSE.txt');
		$my_update_checker = PucFactory::buildUpdateChecker(
			'https://updates.insightengine.online/wp-update-server/?action=get_metadata&slug=aielatex&token='.$token,
			__FILE__,
			'aielatex'
		);
	}
});
