<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.insightengine.online/
 * @since      1.0.0
 *
 * @package    Aielatex
 * @subpackage Aielatex/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Aielatex
 * @subpackage Aielatex/public
 * @author     Kevin K. @ Insight Engine <kevinkno@gmail.com>
 */
class Aielatex_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_register_style( 'katex', plugin_dir_url( __FILE__ ) . 'css/katex.min.css', array(), '0.16.11', 'all' );
		wp_register_style( 'aielatex-public', plugin_dir_url( __FILE__ ) . 'css/aielatex-public.css', array( 'katex' ), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( 'katex', plugin_dir_url( __FILE__ ) . 'js/katex.min.js', array(), '0.16.11', true );
		wp_register_script( 'katex-auto-render', plugin_dir_url( __FILE__ ) . 'js/auto-render.min.js', array( 'katex' ), '0.16.11', true );
		wp_register_script( 'aielatex-public', plugin_dir_url( __FILE__ ) . 'js/aielatex-public.js', array( 'jquery', 'katex', 'katex-auto-render' ), $this->version, false );

	}

}
