(function($) {
    'use strict';

    let aielatex = {
        id: null,
        botId: null,
        observe: true,
        index: 0,
        functions: {},
        tippy: {},

        init: function(botId) {
            this.botId = botId;
        },

        getBotId: function(chatbot) {
            var botId = $(chatbot).attr('id').split('mwai-chatbot-')[1];
            return botId;
        },

        parse: function(reply,args) {
            setTimeout(() => {
                let content = reply;
                content = content.replace(/\\/g, '|');
                this.replaceMessage(content,args.botId);
            }, 100);
            return reply;
        },

        removeFromContext: function(botId, messageIndex, context, chatbot) {
            context.messages.splice(messageIndex, 1);
            chatbot.setContext(context);
            //console.log('Removed', messageIndex);
            return context;
        },
        insertIntoContext: function(botId, messageIndex, context, chatbot, message) {
            context.messages.splice(messageIndex, 0, message);
            chatbot.setContext(context);
            //console.log('Inserted',messageIndex);
            return context;
        },
        replaceMessage: function(text, botId) {
            var chatbot = jQuery('#mwai-chatbot-' + botId);
            //console.log('chatbot', chatbot,'for',botId);
            var messageIndex = jQuery(chatbot).find('.mwai-text').length - 1;
            //console.log('messageIndex', messageIndex);
            // retrieve context from local storage

            var context = localStorage.getItem('mwai-chat-' + botId);
            var context = JSON.parse(context);
            //console.log(context);
        
            var the_message = context.messages[messageIndex];
            the_message.content = text;
            //console.log('the_message',the_message);
            chatbot = MwaiAPI.getChatbot(botId);
            context = this.removeFromContext(botId, messageIndex, context, chatbot);
            context = this.insertIntoContext(botId, messageIndex, context, chatbot, the_message);
            localStorage.setItem('mwai-chat-' + botId, JSON.stringify(context));
        },
        parseHTML: function(paragraph, newReply, botId) {
            const paragraphContent = $(paragraph).html();
            if (paragraphContent.includes('<span style="opacity:') || paragraphContent.includes('BlinkingCursor')) {
                return paragraphContent;
            }
            
            // Create a temporary container
            const tempContainer = document.createElement('div');
            tempContainer.innerHTML = paragraphContent;
            
            // Replace | with \
            let content = tempContainer.innerHTML;
            content = content.replace(/\|/g, '\\');

            // Remove line breaks and <br> tags within square brackets
            content = content.replace(/\[([^\]]+)\]/gs, function(match, p1) {
                return '[' + p1.replace(/[\r\n]+|<br\s*\/?>/gi, '') + ']';
            });

            // Replace <em> and </em> with underscores
            content = content.replace(/<em>|<\/em>/g, '_');

            tempContainer.innerHTML = content;
            
            // Use renderMathInElement to render LaTeX in the container
            renderMathInElement(tempContainer);

            // Get the HTML content of the temporary container
            const html = tempContainer.innerHTML;
            tempContainer.remove();

            return html;
        },

        processChatbot: function(chatbotElement,botId) {
            var success = false;
            const replies = chatbotElement.querySelectorAll('.mwai-reply');
            replies.forEach(reply => {
                if (reply.classList.contains('mwai-ai')) {
                    const newReply = false;
                    const paragraphs = jQuery(reply).find('p,ol,ul');
                    paragraphs.each(function() {
                        const paragraph = jQuery(this);
                        const newHTML = aielatex.parseHTML(paragraph,newReply,botId);
                        if (paragraph.html() !== newHTML) {
                            console.log('newHTML',newHTML,'vs',paragraph.html());
                            if (!newHTML) { paragraph.remove(); } else { paragraph.html(newHTML); }
                            success = true;
                        }
                    });
                }
            });
            return success;
        },

        setupObserver: function(chatbotElement,botId) {
            const conversationObserver = new MutationObserver((mutationsList, observer) => {
                if (!aielatex.observe) {
                    return;
                }

                var reply = chatbotElement.querySelectorAll('.mwai-reply');
                if (reply.length > 0) {
                    reply = reply[reply.length - 1];
                    if (reply && reply.classList.contains('mwai-ai')) {
                        const paragraphs = jQuery(reply).find('p,ol,ul');
                        paragraphs.each(function() {
                            const paragraph = jQuery(this);
                            const newHTML = aielatex.parseHTML(paragraph,true,botId);
                            //console.log('newHTML',newHTML,'vs',paragraph.html());
                            if (paragraph.html() !== newHTML) {
                                console.log('newHTML',newHTML,'vs',paragraph.html());
                                aielatex.observe = false;
                                if (!newHTML) { paragraph.remove(); } else { paragraph.html(newHTML); }
                                setTimeout(() => { aielatex.observe = true; }, 100);
                            }
                        });
                    }
                }
            });

            const observerConfig = { 
                childList: true,
                subtree: true,
                characterData: true
            };
            const conversationElement = chatbotElement.querySelector('.mwai-conversation');
            if (conversationElement) {
                conversationObserver.observe(conversationElement, observerConfig);
            }
        }
    };

    (function waitForMwaiAPI(startTime) {
        if (typeof MwaiAPI !== 'undefined' && document.querySelector('.mwai-chatbot')) {
            
            MwaiAPI.addFilter('ai.reply', function(reply,args) { return aielatex.parse(reply,args); });
            console.log('aielatex started');

            // Add a click event listener to the document
            document.addEventListener('click', function() {
                // Process all chatbot elements when the page is clicked
                document.querySelectorAll('.mwai-chatbot').forEach(chatbotElement => {
                    const botId = aielatex.getBotId(chatbotElement);
                    setTimeout(() => {
                        aielatex.observe = false;
                        const success = aielatex.processChatbot(chatbotElement,botId);
                        aielatex.observe = true;
                        if (success) {
                            aielatex.setupObserver(chatbotElement,botId);
                        }
                    }, 100);
                });
            });
            
            // Set up observer on .mwai-chatbot to look for changes to .mwai-conversation
            const chatbotElements = document.querySelectorAll('.mwai-chatbot');
            
            chatbotElements.forEach(chatbotElement => {
                const botId = aielatex.getBotId(chatbotElement);
                aielatex.processChatbot(chatbotElement,botId);
                aielatex.setupObserver(chatbotElement,botId);
            });
        } else {
            if (Date.now() - startTime < 3000) {
                setTimeout(() => waitForMwaiAPI(startTime), 100);
            }
        }

    })(Date.now());
})(jQuery);